==> UDFTOIDL.3.3r6.tar: FhClose.c <==
#include <stdlib.h>
#include <stdio.h>
#include "util_str.h"
#include "ret_codes.h"
#include "gen_defs.h"
#include "libbase_udf.h"

#ifdef _IDL_EXPORT_
#include "idl_export.h"
#else
#include "export.h"
#endif

#include "udfdlm_defs.h"
#include "udfdlm_ansi.h"

void FhClose( ByTe_4 fhN )
{
    extern struct fh_cache fh_list[];
  
    struct fh_cache *fh;
    struct Pidf     *P;
    ByTe_4 I, EnD;
 
    fh = &fh_list[fhN];

    if (fh->dA != NULL)      { free (fh->dA);           }
    if (fh->vA != NULL)      { free (fh->vA);           }
    if (fh->Begs != NULL)    { free ((void *)fh->Begs); }
    if (fh->AncInfo != NULL) { free (fh->AncInfo);      }
    if (fh->Order != NULL)   { free(fh->Order);         }
    if (fh->pInfo != NULL)   { free(fh->pInfo);         }
    if (fh->mV != NULL) {
        EnD = 2 * (fh->nT + fh->nC) + 1;
        for (I = 0; I < EnD; ++I) {
            if (fh->mV[I] != NULL) { free(fh->mV[I]); }
        }
        free(fh->mV);
     }

    if ( fh->PIDF != NULL ) {
       P = (struct Pidf *)fh->PIDF;
       if (P->Fp != 0)            { fclose (P->Fp);       }  
       if (P->Groups != NULL)     { free (P->Groups);     }
       if (P->Units != NULL)      { free (P->Units);      }
       if (P->Sensors != NULL)    { free (P->Sensors);    }
       if (P->Scans != NULL)      { free (P->Scans);      }
       if (P->Ancil != NULL)      { free (P->Ancil);      }
       if (P->Modes != NULL)      { free (P->Modes);      }
       if (P->Bins != NULL)       { free (P->Bins);       }
       if (P->CMisc != NULL)      { free (P->CMisc);      }
       if (P->SMisc != NULL)      { free (P->SMisc);      }
       if (P->Pi.LatLong != NULL) { free (P->Pi.LatLong); }
       free (fh->PIDF);
    }

    fh->Order   = NULL;
    fh->Units   = NULL;
    fh->Dim     = NULL;
    fh->Loc     = NULL;
    fh->Set     = NULL;
    fh->uNDef   = NULL;
    fh->Begs    = NULL;
    fh->dA      = NULL;
    fh->vA      = NULL;
    fh->AncInfo = NULL;
    fh->pInfo   = NULL;
    fh->sdef    = NULL;
    fh->PIDF    = NULL;
    fh->mV      = NULL;
    fh->tV      = 0;
    fh->Key     = 0;
    fh->dSize   = 0;
    fh->vSize   = 0;
    fh->flags.baseunit = 1;
    fh->is_open = 0;
}

==> UDFTOIDL.3.4r2.tar: FhClose.c <==
#include <stdlib.h>
#include <stdio.h>
#include "util_str.h"
#include "ret_codes.h"
#include "gen_defs.h"
#include "libbase_udf.h"

#ifdef _IDL_EXPORT_
#include "idl_export.h"
#else
#include "export.h"
#endif

#include "udfdlm_defs.h"
#include "udfdlm_ansi.h"

void FhClose( ByTe_4 fhN )
{
    extern struct fh_cache fh_list[];
  
    struct fh_cache *fh;
    struct Pidf     *P;
    ByTe_4 I, EnD;
 
    fh = &fh_list[fhN];

    if (fh->dA != NULL)      { free (fh->dA);           }
    if (fh->Order != NULL)   { free(fh->Order);         }
    if (fh->pInfo != NULL)   { free(fh->pInfo);         }
    if (fh->mV != NULL) {
        EnD = 2 * (fh->nT + fh->nC) + 1;
        for (I = 0; I < EnD; ++I) {
            if (fh->mV[I] != NULL) { free(fh->mV[I]); }
            if (fh->vA[I] != NULL) { free(fh->vA[I]); }
        }
        free(fh->mV);
        free(fh->vA);
     }

    if ( fh->PIDF != NULL ) {
       P = (struct Pidf *)fh->PIDF;
       if (P->Fp != 0)            { fclose (P->Fp);       }  
       if (P->Groups != NULL)     { free (P->Groups);     }
       if (P->Units != NULL)      { free (P->Units);      }
       if (P->Sensors != NULL)    { free (P->Sensors);    }
       if (P->Scans != NULL)      { free (P->Scans);      }
       if (P->Ancil != NULL)      { free (P->Ancil);      }
       if (P->Modes != NULL)      { free (P->Modes);      }
       if (P->Bins != NULL)       { free (P->Bins);       }
       if (P->CMisc != NULL)      { free (P->CMisc);      }
       if (P->SMisc != NULL)      { free (P->SMisc);      }
       if (P->Pi.LatLong != NULL) { free (P->Pi.LatLong); }
       free (fh->PIDF);
    }

    fh->Order   = NULL;
    fh->Units   = NULL;
    fh->Dim     = NULL;
    fh->Loc     = NULL;
    fh->Set     = NULL;
    fh->uNDef   = NULL;
    fh->dA      = NULL;
    fh->vA      = NULL;
    fh->pInfo   = NULL;
    fh->sdef    = NULL;
    fh->PIDF    = NULL;
    fh->mV      = NULL;
    fh->tV      = 0;
    fh->Key     = 0;
    fh->dSize   = 0;
    fh->vNum    = 0;
    fh->TotSeN  = 0;
    fh->flags.baseunit = 1;
    fh->is_open = 0;
}
